@@ -9,6 +9,7 @@ from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, Decr
 from django.db.models import Q
 from firebase_admin import db
 from django.conf import settings
+from django.utils.dateformat import format
 
 DEFAULT_APP = settings.DEFAULT_APP
 FIREBASE_REF = settings.FIREBASE_REF
@@ -458,7 +459,7 @@ class StickProtocol():
             signedPreKeys = []
             for spk in signedPreKeysList:
                 key = {'id': spk.keyId, 'public': spk.public, 'cipher': spk.cipher, 'salt': spk.salt,
-                       'signature': spk.signature, 'active': spk.active, 'timestamp': spk.timestamp}
+                       'signature': spk.signature, 'active': spk.active, 'timestamp': int(format(spk.timestamp, 'U')) * 1000}
                 signedPreKeys.append(key)
             bundle['signedPreKeys'] = signedPreKeys
             preKeys = []
